@@ -21,6 +21,6 @@ def initialise(projectname: str, no_init: bool, no_install: bool) -> None:
 
     # Whether to init the git repo
     if not no_init:
-        git_init = ['git init', 'git add -A', 'git commit -m "first commit"']
+        git_init = ['git init --initial-branch=main', 'git add -A', 'git commit -m "first commit"']
         for cmd in git_init:
             os.system(cmd)
