@@ -42,34 +42,7 @@ def main():
     create-pyproj <projectname> [options]
 
     The project structure will be copied to a folder ./<projectname>, the modules installed with Pipenv and a git repo initiated.
-
-    This basic version starts with:
-        - a settings manager to save, load and update using yaml.
-        - a logging setup with console and file handlers.
-        - a version manager, to keep the version file easily asccessible for CI/CD
-
-    Project structure:
-        - .vscode
-            - settings.json
-            - extensions.json
-        - src
-            - _config
-                - logging.py
-                - logging.yaml
-                - settings.py
-                - version.py
-            - main.py
-            - settings.yaml
-        - .env
-        - .flake8
-        - .style.yapf
-        - .gitignore
-        - Pipfile
-        - README.md
-        - VERSION
-
-
-        '''))
+    '''))
     parser.add_argument('projectname', help='The name of the project you want to start.')
     parser.add_argument('--python_version',
                         action='store',
